==> keyclic_sdk_api-2.2.12.tar.gz: lib/model/webhook_links_self_iri_template.dart <==
part of keyclic_sdk_api.api;

class WebhookLinksSelfIriTemplate {
  WebhookLinksSelfIriTemplate({
    this.mapping,
  });

  factory WebhookLinksSelfIriTemplate.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return WebhookLinksSelfIriTemplate(
      mapping: WebhookLinksSelfIriTemplateMapping.fromJson(json['mapping']),
    );
  }

  WebhookLinksSelfIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is WebhookLinksSelfIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<WebhookLinksSelfIriTemplate> listFromJson(List<dynamic> json) {
    return json == null
        ? <WebhookLinksSelfIriTemplate>[]
        : json
            .map((dynamic value) => WebhookLinksSelfIriTemplate.fromJson(value))
            .toList();
  }

  static Map<String, WebhookLinksSelfIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, WebhookLinksSelfIriTemplate>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = WebhookLinksSelfIriTemplate.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping,
    };
  }

  @override
  String toString() {
    return 'WebhookLinksSelfIriTemplate[mapping=$mapping, ]';
  }
}

==> keyclic_sdk_api-2.3.8.tar.gz: lib/model/webhook_links_self_iri_template.dart <==
part of keyclic_sdk_api.api;

class WebhookLinksSelfIriTemplate {
  WebhookLinksSelfIriTemplate({
    this.mapping,
  });

  factory WebhookLinksSelfIriTemplate.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return WebhookLinksSelfIriTemplate(
      mapping: WebhookLinksSelfIriTemplateMapping.fromJson(json['mapping']),
    );
  }

  WebhookLinksSelfIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is WebhookLinksSelfIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<WebhookLinksSelfIriTemplate> listFromJson(List<dynamic> json) {
    return json
            ?.map(
                (dynamic value) => WebhookLinksSelfIriTemplate.fromJson(value))
            ?.toList() ??
        <WebhookLinksSelfIriTemplate>[];
  }

  static Map<String, WebhookLinksSelfIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    return json?.map((String key, dynamic value) {
          return MapEntry(key, WebhookLinksSelfIriTemplate.fromJson(value));
        }) ??
        <String, WebhookLinksSelfIriTemplate>{};
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping.toJson(),
    };
  }

  @override
  String toString() {
    return 'WebhookLinksSelfIriTemplate[mapping=$mapping, ]';
  }
}
